import { CustomMDX } from "@/app/components/mdx-components";
import { Metadata } from "next";
import { generateEmbed } from "@/app/common/embed";
import { Title } from "@/app/components/title";
import { DocsContentMetadata, getDocContent, getDocsContent } from "@/app/common/documentation";
import { notFound } from "next/navigation";
import { GithubLink } from "@/app/components/docs/github-link";
import { DocsBreadcrumb } from "@/app/components/docs/breadcrumb";

type DocumentationPageParams = {
  params: {
    /**
     * The slug for the documentation page.
     */
    slug?: string[];
  };
};

export async function generateStaticParams() {
  let documentationPages: DocsContentMetadata[] = getDocsContent();

  return documentationPages.map(page => ({
    slug: [page.slug],
  }));
}

export async function generateMetadata({ params: { slug } }: DocumentationPageParams): Promise<Metadata> {
  const page: DocsContentMetadata | undefined = getDocContent(slug);

  // Fallback to page not found
  if (!page) {
    return generateEmbed({
      title: "Page not found",
      description: "The documentation page was not found",
    });
  }

  return generateEmbed({
    title: `${page.title} - Documentation`,
    description: `${page.summary}\n\nClick to view this page`,
  });
}

export default function Page({ params: { slug } }: DocumentationPageParams) {
  const page: DocsContentMetadata | undefined = getDocContent(slug);

  // Page was not found, show an error page
  if (!page) {
    return notFound();
  }

  return (
    <div className="w-full h-full px-4 flex flex-col gap-2">
      <div className="flex justify-between items-center">
        {/* The breadcrumb for the documentation page */}
        <DocsBreadcrumb page={page} />

        {/* The Git link for the documentation page */}
        <div className="flex flex-row gap-2 items-center">
          <GithubLink page={page} />
        </div>
      </div>

      {/* The documentation page title and description */}
      <div className="text-center mb-4">
        <Title title={page.title} subtitle={page.summary} />
      </div>

      {/* The content of the documentation page */}
      <div className="text-left w-full pb-[2rem]">
        <CustomMDX source={page.content} />
      </div>
    </div>
  );
}
